Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7632)

Unified Diff: chrome/common/spellcheck_messages.h

Issue 11445002: Sync user's custom spellcheck dictionary (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Add server-side size limit tests Created 7 years, 12 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/common/spellcheck_messages.h
diff --git a/chrome/common/spellcheck_messages.h b/chrome/common/spellcheck_messages.h
index e6036b70298463f3475bd647aa4b56033db64130..d8bebdb94d15673279a9e08471f56221afc430c8 100644
--- a/chrome/common/spellcheck_messages.h
+++ b/chrome/common/spellcheck_messages.h
@@ -35,15 +35,11 @@ IPC_MESSAGE_CONTROL4(SpellCheckMsg_Init,
std::string /* language */,
bool /* auto spell correct */)
-// A word has been added to the custom dictionary; update the local custom
-// word list.
-IPC_MESSAGE_CONTROL1(SpellCheckMsg_WordAdded,
- std::string /* word */)
-
-// A word has been removed from the custom dictionary; update the local custom
-// word list.
-IPC_MESSAGE_CONTROL1(SpellCheckMsg_WordRemoved,
- std::string /* word */)
+// Words have been added and removed in the custom dictionary; update the local
+// custom word list.
+IPC_MESSAGE_CONTROL2(SpellCheckMsg_WordsAddedRemoved,
+ std::vector<std::string> /* words_added */,
+ std::vector<std::string> /* words_removed */)
// Toggle the auto spell correct functionality.
IPC_MESSAGE_CONTROL1(SpellCheckMsg_EnableAutoSpellCorrect,
@@ -51,13 +47,13 @@ IPC_MESSAGE_CONTROL1(SpellCheckMsg_EnableAutoSpellCorrect,
#if !defined(OS_MACOSX)
// Sends text-check results from the Spelling service when the service finishes
-// checking text reveived by a SpellCheckHostMsg_CallSpellingService message.
-// If the service is not available, the 4th parameter should be false and
-// the 5th parameter should contain the requested sentence.
+// checking text received by a SpellCheckHostMsg_CallSpellingService message.
+// If the service is not available, the 4th parameter should be false and the
+// 5th parameter should contain the requested sentence.
IPC_MESSAGE_ROUTED5(SpellCheckMsg_RespondSpellingService,
int /* request identifier given by WebKit */,
int /* offset */,
- bool /* succeeded calling serivce */,
+ bool /* succeeded calling service */,
string16 /* sentence */,
std::vector<SpellCheckResult>)
#endif
@@ -67,7 +63,7 @@ IPC_MESSAGE_ROUTED5(SpellCheckMsg_RespondSpellingService,
// sent when the user clicks the "Find Next" button on the spelling panel.
IPC_MESSAGE_ROUTED0(SpellCheckMsg_AdvanceToNextMisspelling)
-// Sends when NSSpellChecker finishes checking text received by a preceeding
+// Sends when NSSpellChecker finishes checking text received by a preceding
// SpellCheckHostMsg_RequestTextCheck message.
IPC_MESSAGE_ROUTED2(SpellCheckMsg_RespondTextCheck,
int /* request identifier given by WebKit */,

Powered by Google App Engine
This is Rietveld 408576698